<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="lt" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Apie</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategorija:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Paleisti torentą</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Praleisti maišos tikrinimą</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Sukurti poaplankį</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torento tvarkymo veiksena:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Visi</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Be kategorijos</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Pridėti kategoriją...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Šalinti kategoriją</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Šalinti nenaudojamas kategorijas</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Pratęsti torentus</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pristabdyti torentus</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Ištrinti torentus</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nauja kategorija</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Taisyti kategoriją...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Išeiti iš qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Po vieną nuorodą eilutėje</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Visuotinio išsiuntimo greičio apribojimas privalo būti arba aukštesnis už 0, arba išjungtas.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Visuotinio atsiuntimo greičio apribojimas privalo būti arba aukštesnis už 0, arba išjungtas.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatyvus išsiuntimo greičio apribojimas privalo būti arba aukštesnis už 0, arba išjungtas.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatyvus atsiuntimo greičio apribojimas privalo būti arba aukštesnis už 0, arba išjungtas.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Didžiausias aktyvių atsiuntimų kiekis privalo būti didesnis nei -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Didžiausias aktyvių išsiuntimų kiekis privalo būti didesnis nei -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Didžiausias aktyvių torentų kiekis privalo būti didesnis nei -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Didžiausias prisijungimų kiekis privalo būti arba aukštesnis už 0, arba išjungtas.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Didžiausias prisijungimų kiekis vienam torentui privalo būti arba aukštesnis už 0, arba išjungtas.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Didžiausias išsiuntimo prisijungimų kiekis vienam torentui privalo būti arba aukštesnis už 0, arba išjungtas.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Nepavyko išsaugoti programos nuostatų, qBittorrent tikriausiai yra nepasiekiama.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent Freenode serveryje</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nežinoma</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Dalinimosi santykio apribojimas privalo būti tarp 0 ir 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Skleidimo laiko riba privalo būti tarp 0 ir 525600 minučių.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Įeinančių susijungimų prievadas privalo būti tarp 1 ir 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Tinklo naudotojo sąsajos prievadas privalo būti tarp 1 ir 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Negalima prisijungti, qBittorrent, tikriausiai, yra nepasiekamas.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Neteisingas naudotojo vardas ar slaptažodis.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prisijungimas</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Pirmutiniai autoriai</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Taikyti</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Išsiųsti torentus</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Failus išsaugoti į:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Slapukas:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Čia įveskite aplanką</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Daugiau informacijos</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informacija apie liudijimus</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nustatyti vietą</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Apriboti išsiuntimo greitį</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Apriboti atsiuntimo greitį</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Pervadinti torentą</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Kita...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Pirmadieniais</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Antradieniais</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Trečiadieniais</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Ketvirtadieniais</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Penktadieniais</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Šeštadieniais</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sekmadieniais</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Atsisiųsti torentus iš jų URL arba Magnet nuorodų</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Išsiųsti vietinį torentą</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Ar tikrai norite pašalinti pasirinktus torentus iš siuntimų sąrašo?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Išsaugoti</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent klientas nepasiekiamas</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Visuotinis išsiuntimo lizdų apribojimo skaičius privalo būti didesnis už 0 arba išjungtas.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Neteisingas kategorijos pavadinimas:\nPrašome kategorijos pavadinime nenaudoti jokių specialių simbolių.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Nepavyko sukurti kategorijos</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Išsiuntimo greičio slenkstis privalo būti didesnis už 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Taisyti</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Laisva vieta: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torento neveiklumo laikmatis privalo būti didesnis už 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Išsaugojimo tvarkymas</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Atsiuntimo greičio slenkstis privalo būti didesnis už 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent išjungta</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Taisyti</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Priemonės</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Failas</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Rodymas</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Parinktys...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Tęsti</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Žemiausia svarba</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Aukščiausia svarba</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Sumažinti svarbą</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Padidinti svarbą</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Viršutinė įrankių juosta</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Būsenos juosta</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Greitis pavadinimo juostoje</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Paaukoti!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Tęsti visus</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pristabdyti visus</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Pridėti torento failą...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Pridėti torento nuorodą...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Taip</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Visuotinis išsiuntimo greičio apribojimas</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Visuotinis atsiuntimo greičio apribojimas</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Ar tikrai norite išeiti iš qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[A: %1, I: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternatyvūs greičio apribojimai</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Paieškos sistema</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtruoti torentų sąrašą...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Paieška</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Siuntimai</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Atsiuntimai</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Jungiamumas</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Greitis</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Tinklo sąsaja</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Kalba</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Naudotojo sąsajos kalba:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Pabaigus atsiuntimą, pranešti el. paštu</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Užbaigus torento siuntimą, paleisti išorinę programą</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP filtravimas</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Planuoti alternatyvių greičio apribojimų naudojimą</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Siuntimų eilė</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Skleisti torentus, kol jų skleidimo laikas pasieks</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Į naujus atsiuntimus, automatiškai pridėti šiuos seklius:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Tinklo naudotojo sąsaja (Nuotolinis valdymas)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP adresas:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Serverio domenai:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Naudoti HTTPS vietoje HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Apeiti atpažinimą klientams, esantiems vietiniame serveryje</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Apeiti atpažinimą klientams, kurie yra IP potinklių baltajame sąraše</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Atnaujinti mano dinaminį domeno vardą</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Nebaigtus siuntimus laikyti čia:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopijuoti .torrent failus į:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopijuoti baigtų atsiuntimų .torrent failus į:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Iš anksto priskirti disko vietą visiems failams</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Pridėti .!qB plėtinį nebaigtiems siųsti failams</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Automatiškai pridėti torentus iš:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP serveris:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Šis serveris reikalauja saugaus susijungimo (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Atpažinimas</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Naudotojo vardas:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Slaptažodis:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Įjungtas protokolas:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP ir μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Klausymosi prievadas</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Prievadas, naudojamas įeinantiems sujungimams:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Naudoti UPnP / NAT-PMP prievadų nukreipimą mašrutizatoriuje</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Kiekvieno paleidimo metu naudoti skirtingą prievadą</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Prisijungimų apribojimai</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Didžiausias prisijungimų skaičius vienam torentui:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Visuotinis didžiausias prisijungimų skaičius:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Didžiausias išsiuntimo prisijungimų skaičius vienam torentui:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Visuotinis didžiausias leistinas išsiuntimo prisijungimų skaičius:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipas:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(jokio)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Serveris:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Prievadas:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Naudoti įgaliotąjį serverį susijungimams su siuntėjais</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Išjungti įgaliotųjų serverių nepalaikomus ryšius</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Naudoti įgaliotąjį serverį tik torentams</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Kelias iki filtro (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Rankiniu būdu uždrausti IP adresai...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Taikyti sekliams</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Visuotinis greičio ribojimas</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Išsiuntimo:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Atsiuntimo:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternatyvūs greičio apribojimai</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Nuo:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Iki:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Kada:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Kasdieną</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Darbo dienomis</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Savaitgaliais</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Greičio apribojimų nustatymai</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Taikyti santykio apribojimą perdavimo pertekliui</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Taikyti greičio apribojimus µTP protokolui</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privatumas</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Įjungti DHT (decentralizuotą tinklą), kad būtų rasta daugiau siuntėjų</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Įjungti apsikeitimą siuntėjais (PeX), kad būtų rasta daugiau siuntėjų</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Įjungti vietinių siuntėjų aptikimą, kad būtų rasta daugiau siuntėjų</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Šifravimo veiksena:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Teikti pirmenybę šifravimui</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Reikalauti šifravimo</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Išjungti šifravimą</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Įjungti anoniminę veikseną</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Didžiausias aktyvių atsiuntimų skaičius:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Didžiausias aktyvių išsiuntimų skaičius:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Didžiausias aktyvių torentų skaičius:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Į šiuos apribojimus neįskaičiuoti lėtus torentus</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Dalinimosi santykio ribojimas</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Skleisti torentus, kol jų dalinimosi santykis pasieks</translation>
    </message>
    <message>
        <source>then</source>
        <translation>, o tuomet</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>juos pristabdyti</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>juos pašalinti</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Naudoti UPnP / NAT-PMP, siekiant nukreipti prievadą iš maršrutizatoriaus</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Liudijimas:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Raktas:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registruotis</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domeno vardas:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Palaikomi parametrai (skiriant raidžių dydį):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torento pavadinimas</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategorija</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: Žymės (atskirtos kableliais)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Turinio kelias (toks pats kaip šaknies kelias kelių failų torente)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Šaknies kelias (pirmas torento pakatalogio kelias)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Išsaugojimo kelias</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Failų skaičius</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torento dydis (baitais)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Esamas seklys</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Informacijos maiša</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Patarimas: Tam, kad tekstas nebūtų apkirptas ties tarpais, rašykite parametrą kabutėse (pvz., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Tinklo sąsajos naudotojo vardas privalo būti bent 3 simbolių ilgio.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Tinklo sąsajos naudotojo slaptažodis privalo būti bent 6 simbolių ilgio.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>min.</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Įjungti apsaugą nuo spustelėjimų ant melagingų objektų</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Įjungti apsaugą nuo užklausų tarp svetainių klastojimo (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Po to ištrinti .torrent failus</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Atsiuntimo greičio slenkstis:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Išsiuntimo greičio slenkstis:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Keisti dabartinį slaptažodį</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatinė</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Naudoti alternatyvią tinklo naudotojo sąsają</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Numatytasis išsaugojimo kelias:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Alternatyvi tinklo sąsajos failų vieta negali būti tuščia.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Nepradėti atsiuntimų automatiškai</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Perjungti torentą į rankinę veikseną</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Kai pasikeičia torento kategorija:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Perkelti paveiktus torentus</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Taikyti greičio apribojimus siuntėjams LAN tinkle</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 reiškia neribotai</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Perkelti torentą</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Kai pasikeičia numatytasis išsaugojimo kelias:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Įjungti serverio antraštės patvirtinimą</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Saugumas</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Kai pasikeičia kategorijos išsaugojimo kelias:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Torentams su keliais failais kurti poaplankį</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sek.</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Perjungti paveiktus torentus į rankinę veikseną</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Failų vieta:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Rankinė</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torento neveiklumo laikmatis:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Numatytoji torento tvarkymo veiksena:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Pridedant torentą</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Prievadas</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Vėliavos</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Jungiamumas</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klientas</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Eiga</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Atsiuntimo greitis</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Išsiuntimo greitis</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Atsiųsta</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Išsiųsta</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Tinkamumas</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Failai</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Šalis</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Įprasta</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Aukšta</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Aukščiausia</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Sekliai</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Siuntėjai</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP šaltiniai</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Failai</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Atsisiųsta:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Siuntimas</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Aktyvus:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Dar liko laukti:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Išsiųsta:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Skleidėjai:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Atsiuntimo greitis:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Išsiuntimo greitis:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Siuntėjai:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Atsiuntimo riba:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Išsiuntimo riba:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Iššvaistyta:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Prisijungimai:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentaras:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Dalinimosi santykis:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Atnaujinama po:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Paskutinį kartą matytas užbaigtu:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Bendras dydis:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Dalys:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Sukūrė:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Pridėta:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Užbaigta:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Sukurtas:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torento maiša:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Išsaugojimo kelias:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Niekada</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (turima %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 šiame seanse)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (daugiausiai %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (viso %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (vidut. %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Atsiuntimo riba:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Išsiuntimo riba:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Stebimas aplankas</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Nustelbti išsaugojimo vietą</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Stebimas aplankas</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Numatytoji išsaugojimo vieta</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Naudotojo statistika</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Podėlio statistika</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Kreipiniai į skaitymo podėlį:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Vidutinė laukimo eilėje trukmė:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Prisijungusių siuntėjų:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Viso laikotarpio dalijimosi santykis:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Viso laikotarpio atsiuntimas:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Iššvaistyta per seansą:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Viso laikotarpio išsiuntimas:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Bendras buferio dydis:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Greitaveikos statistika</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>I/O darbai eilėje:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Rašymo podėlio perkrova:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Skaitymo podėlio perkrova:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Bendras eilės dydis:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 mazgų</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Visi (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Atsiunčiami (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Skleidžiami (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Užbaigti (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Pratęsti (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pristabdyti (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktyvūs (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Neaktyvūs (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Klaida (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Visi (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Atsiunčiami (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Skleidžiami (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Užbaigti (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pristabdyti (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Pratęsti (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktyvūs (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Neaktyvūs (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Klaida (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Vardas</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Eiga</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Atsiuntimo svarba</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Liko</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Prieinamumas</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Vardas</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Baigta</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Būsena</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Skleidėjai</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Siuntėjai</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Ats. greitis</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Išs. greitis</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Santykis</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Liko</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorija</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Žymės</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Pridėta</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Užbaigta</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Seklys</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Ats. riba</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Išs. riba</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Atsiųsta</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Išsiųsta</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Atsiųsta per seansą</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Išsiųsta per seansą</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Liko</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Aktyvus</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Atsiuntimo vieta</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Užbaigta</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Dalijimosi santykio riba</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Paskutinį kartą matytas užbaigtu</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Paskutinė veikla</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Bendras Dydis</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Būsena</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Siuntėjai</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Žinutė</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Atsiųsta</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Seklio URL:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Atnaujinama...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Veikia</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Dar nesusisiekta</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Skleidėjai</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Neveikia</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Kopijuoti seklio URL</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Pridėti naują seklį...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Taisyti seklio URL...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Seklio taisymas</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Siunčia</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Šalinti seklį</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Seklių pridėjimo vediklis</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Norimų pridėti seklių sąrašas (po vieną eilutėje):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>prieš %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Paskirstoma</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Užbaigta</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Perkeliama</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Skleidžiama</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Skleidžiama</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Eilėje</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Atsiunčiama</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Atsiunčiami metaduomenys</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Tikrinama</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Trūksta failų</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Eilėje patikrinimui</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Atsiunčiama</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Tikrinami pratęsimo duomenys</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Laukiama</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Būsena</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorijos</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torento atsiuntimo greičio ribojimas</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torento išsiuntimo greičio ribojimas</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Tęsti</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Priverstinai pratęsti</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Apriboti dalijimosi santykį...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Apriboti išsiuntimo greitį...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Apriboti atsiuntimo greitį...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Aukštyn</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Žemyn</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Į viršų</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Į apačią</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Nustatyti saugojimo vietą...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Kopijuoti pavadinimą</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Kopijuoti maišą</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Visų pirma siųsti pirmas ir paskutines dalis</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatinis torento tvarkymas</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorija</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nauja...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Atstatyti</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Svarba</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Priverstinai pertikrinti</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Kopijuoti Magnet nuorodą</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Super skleidimo režimas</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Pervadinti...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Siųsti dalis iš eilės</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Priverstinai pertikrinti</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nauja kategorija</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Vieta</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Naujas pavadinimas</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nustatyti vietą</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Priverstinai siųsti atnaujinimus</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Taisyti kategoriją</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Išsaugojimo kelias</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torentų Išsiuntimo/Atsiuntimo santykio ribojimas</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Naudoti visuotinį dalinimosi apribojimą</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Nenustatinėti jokio dalinimosi apribojimo</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Nustatyti dalinimosi apribojimą į</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>santykis</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minučių</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Pažangus BitTorrent klientas, parašytas C++ programavimo kalba, naudojant Qt bei libtorrent-rasterbar bibliotekas.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Svetainė internete:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Diskusijų forumas:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Klaidų seklys:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Ištrynimo patvirtinimas</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Taipogi ištrinti failus iš kietojo disko</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Ištrynimo patvirtinimas - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Atsisiųsti iš URL adresų</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Atsiųsti</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Pridėti torentų nuorodas</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 val. %2 min.</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 d. %2 val.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Nežinoma</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 min.</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 min.</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Išsaugojimo kelias yra tuščias</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Papildinio kelias:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL arba vietinis katalogas</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Įdiegti papildinį</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Gerai</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Skleidėjai:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Visi papildiniai</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dydis:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Paieška</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Paieškos papildiniai...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Visos kategorijos</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Ieškoti:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Kopijuoti aprašo puslapio URL</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Eiti į aprašo puslapį</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Rezultatai (rodoma</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Atsisiųsti</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtras</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Tik torentų pavadinimuose</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Tik įjungti</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>iš</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Visur</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Pašalinti</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Įdiegti naują papildinį</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Naujus paieškos sistemų papildinius galite gauti čia:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Įdiegti paieškos papildiniai:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Įjungta</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Įspėjimas: Atsisiųsdami failus iš šių paieškos sistemų, būkite susipažinę su savo šalies autorių teisių įstatymais.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Tikrinti, ar yra atnaujinimų</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Paieškos papildiniai</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Siuntėjai</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Paieškos sistema</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Skleidėjai</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Įjungta</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versija</translation>
    </message>
</context>
</TS>